@@ -9,4 +9,4 @@ if __name__ == "__main__":
     # Enumerate the available Pixelblazes on the network.
     for ipAddress in Pixelblaze.EnumerateAddresses(timeout=1500):
         with Pixelblaze(ipAddress) as pixelblaze:
-            print(f"    at {ipAddress} found '{pixelblaze.getDeviceName()}'")
+            print(f"    at {ipAddress} found '{pixelblaze.getConfigSettings()}'")
